@@ -216,38 +216,37 @@ class dyn_obj:
         frames = self.frames
         """:type: `np.ndarray`: the frames that Blender will animate and have corresponding data for"""
 
-        if staticity == "static":
         
-            int_size = len(int_x)
-            int_coords = np.zeros((int_size, 3))
-            int_coords[:, 0] = int_x*self.scale
-            int_coords[:, 1] = int_y*self.scale
-            int_coords[:, 2] = int_z*self.scale
+        int_size = len(int_x)
+        int_coords = np.zeros((int_size, 3))
+        int_coords[:, 0] = int_x*self.scale
+        int_coords[:, 1] = int_y*self.scale
+        int_coords[:, 2] = int_z*self.scale
 
-            int_curve = bpy.data.curves.new(name, type='CURVE')
-            int_curve.dimensions = '3D'
-            int_curve.resolution_u = 2
+        int_curve = bpy.data.curves.new(name, type='CURVE')
+        int_curve.dimensions = '3D'
+        int_curve.resolution_u = 2
 
-            # map coords to spline
-            int_line = int_curve.splines.new('NURBS')
-            int_line.points.add(len(int_coords))
-            for i, coord in enumerate(int_coords):
-                x,y,z = coord
-                int_line.points[i].co = (x, y, z, 1)
+        # map coords to spline
+        int_line = int_curve.splines.new('NURBS')
+        int_line.points.add(len(int_coords))
+        for i, coord in enumerate(int_coords):
+            x,y,z = coord
+            int_line.points[i].co = (x, y, z, 1)
 
-            # create Object
-            int_curveOB = bpy.data.objects.new(name, int_curve)
+        # create Object
+        int_curveOB = bpy.data.objects.new(name, int_curve)
 
-            # attach to scene and validate context
-            bpy.context.collection.objects.link(int_curveOB)
-            
-            int_curveOB.data.bevel_depth = thickness
-            int_curveOB.data.use_fill_caps = True
+        # attach to scene and validate context
+        bpy.context.collection.objects.link(int_curveOB)
+        
+        int_curveOB.data.bevel_depth = thickness
+        int_curveOB.data.use_fill_caps = True
 
-            int_curveOB.data.bevel_factor_start = 0
+        int_curveOB.data.bevel_factor_start = 0
 
-            curve_to_mesh(int_curveOB)
-            self.streamline = bpy.data.objects[self.name+'_streamline']
+        curve_to_mesh(int_curveOB)
+        self.streamline = bpy.data.objects[self.name+'_streamline']
 
         if staticity == 'dynamic':
             int_size = len(int_x)
